@@ -4,7 +4,7 @@ import requests
 from django.utils.log import request_logger
 from requests.exceptions import ConnectionError
 
-from .settings import (SVELTE_RENDERER_PORT, SVELTE_RENDERER_ENABLED)
+from .settings import (SVELTE_RENDERER_HOSTNAME, SVELTE_RENDERER_PORT, SVELTE_RENDERER_ENABLED)
 
 
 def local_renderer(component: str, props: any = None) -> str:
@@ -13,7 +13,8 @@ def local_renderer(component: str, props: any = None) -> str:
     try:
         if not isinstance(props, str):
             props = json.dumps(props)
-        resp = requests.post(f"http://localhost:{SVELTE_RENDERER_PORT}/", json=dict(component=component, props=props))
+        resp = requests.post(f"http://{SVELTE_RENDERER_HOSTNAME}:{SVELTE_RENDERER_PORT}/",
+                             json=dict(component=component, props=props))
         if resp.status_code >= 300:
             request_logger.warn("Renderer backend responded with incorrect status code.")
             return ""
