@@ -40,7 +40,7 @@ function handleMessage(m) {
     }
 }
 
-const client = new WebSocket(`ws://localhost:${window['SVELTE_LIVERELOAD_PORT']}/livereload` || "ws://localhost:5050/livereload");
+const client = new WebSocket(`ws://${window['SVELTE_RELOADING_HOSTNAME'] || 'localhost'}:${window['SVELTE_RELOADING_PORT'] || '5050'}/livereload`);
 client.onopen = function () {
     client.send(JSON.stringify({command: "hello"}))
 }
